diff --git a/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_asset_rewards.rs b/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_asset_rewards.rs
index 8c546ecc1169eebe668a70abdfe20bf7f74f0c32..218c93c51035037e5d325dc5b3d31897e164f0ec 100644
--- a/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_asset_rewards.rs
+++ b/cumulus/parachains/runtimes/assets/asset-hub-rococo/src/weights/pallet_asset_rewards.rs
@@ -17,9 +17,9 @@
 //! Autogenerated weights for `pallet_asset_rewards`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 32.0.0
-//! DATE: 2024-09-17, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! DATE: 2025-01-14, STEPS: `50`, REPEAT: `20`, LOW RANGE: `[]`, HIGH RANGE: `[]`
 //! WORST CASE MAP SIZE: `1000000`
-//! HOSTNAME: `runner-obbyq9g6-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
+//! HOSTNAME: `runner-ys-ssygq-project-674-concurrent-0`, CPU: `Intel(R) Xeon(R) CPU @ 2.60GHz`
 //! WASM-EXECUTION: `Compiled`, CHAIN: `Some("asset-hub-rococo-dev")`, DB CACHE: 1024
 
 // Executed Command:
@@ -64,8 +64,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `358`
 		//  Estimated: `6360`
-		// Minimum execution time: 59_228_000 picoseconds.
-		Weight::from_parts(60_640_000, 0)
+		// Minimum execution time: 65_882_000 picoseconds.
+		Weight::from_parts(67_073_000, 0)
 			.saturating_add(Weight::from_parts(0, 6360))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(5))
@@ -84,8 +84,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `872`
 		//  Estimated: `4809`
-		// Minimum execution time: 55_079_000 picoseconds.
-		Weight::from_parts(56_396_000, 0)
+		// Minimum execution time: 56_950_000 picoseconds.
+		Weight::from_parts(58_088_000, 0)
 			.saturating_add(Weight::from_parts(0, 4809))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(4))
@@ -104,8 +104,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `872`
 		//  Estimated: `4809`
-		// Minimum execution time: 56_585_000 picoseconds.
-		Weight::from_parts(58_067_000, 0)
+		// Minimum execution time: 59_509_000 picoseconds.
+		Weight::from_parts(61_064_000, 0)
 			.saturating_add(Weight::from_parts(0, 4809))
 			.saturating_add(T::DbWeight::get().reads(5))
 			.saturating_add(T::DbWeight::get().writes(4))
@@ -124,8 +124,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `1072`
 		//  Estimated: `6208`
-		// Minimum execution time: 77_177_000 picoseconds.
-		Weight::from_parts(79_034_000, 0)
+		// Minimum execution time: 80_685_000 picoseconds.
+		Weight::from_parts(83_505_000, 0)
 			.saturating_add(Weight::from_parts(0, 6208))
 			.saturating_add(T::DbWeight::get().reads(6))
 			.saturating_add(T::DbWeight::get().writes(4))
@@ -136,8 +136,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `318`
 		//  Estimated: `4809`
-		// Minimum execution time: 16_339_000 picoseconds.
-		Weight::from_parts(16_853_000, 0)
+		// Minimum execution time: 17_032_000 picoseconds.
+		Weight::from_parts(17_628_000, 0)
 			.saturating_add(Weight::from_parts(0, 4809))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -148,8 +148,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `318`
 		//  Estimated: `4809`
-		// Minimum execution time: 16_282_000 picoseconds.
-		Weight::from_parts(16_663_000, 0)
+		// Minimum execution time: 15_290_000 picoseconds.
+		Weight::from_parts(16_212_000, 0)
 			.saturating_add(Weight::from_parts(0, 4809))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -160,8 +160,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `318`
 		//  Estimated: `4809`
-		// Minimum execution time: 17_137_000 picoseconds.
-		Weight::from_parts(17_608_000, 0)
+		// Minimum execution time: 17_721_000 picoseconds.
+		Weight::from_parts(18_603_000, 0)
 			.saturating_add(Weight::from_parts(0, 4809))
 			.saturating_add(T::DbWeight::get().reads(1))
 			.saturating_add(T::DbWeight::get().writes(1))
@@ -180,8 +180,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `747`
 		//  Estimated: `6208`
-		// Minimum execution time: 60_634_000 picoseconds.
-		Weight::from_parts(62_132_000, 0)
+		// Minimum execution time: 67_754_000 picoseconds.
+		Weight::from_parts(69_428_000, 0)
 			.saturating_add(Weight::from_parts(0, 6208))
 			.saturating_add(T::DbWeight::get().reads(6))
 			.saturating_add(T::DbWeight::get().writes(4))
@@ -208,8 +208,8 @@ impl<T: frame_system::Config> pallet_asset_rewards::WeightInfo for WeightInfo<T>
 		// Proof Size summary in bytes:
 		//  Measured:  `1105`
 		//  Estimated: `6208`
-		// Minimum execution time: 118_514_000 picoseconds.
-		Weight::from_parts(121_075_000, 0)
+		// Minimum execution time: 127_524_000 picoseconds.
+		Weight::from_parts(130_238_000, 0)
 			.saturating_add(Weight::from_parts(0, 6208))
 			.saturating_add(T::DbWeight::get().reads(10))
 			.saturating_add(T::DbWeight::get().writes(10))